# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/cjm-fasthtml-media-gallery',
                'doc_host': 'https://cj-mills.github.io',
                'git_url': 'https://github.com/cj-mills/cjm-fasthtml-media-gallery',
                'lib_path': 'cjm_fasthtml_media_gallery'},
  'syms': { 'cjm_fasthtml_media_gallery.components.controls': { 'cjm_fasthtml_media_gallery.components.controls.render_gallery_controls': ( 'components/controls.html#render_gallery_controls',
                                                                                                                                            'cjm_fasthtml_media_gallery/components/controls.py'),
                                                                'cjm_fasthtml_media_gallery.components.controls.render_type_filter_button': ( 'components/controls.html#render_type_filter_button',
                                                                                                                                              'cjm_fasthtml_media_gallery/components/controls.py'),
                                                                'cjm_fasthtml_media_gallery.components.controls.render_type_filters': ( 'components/controls.html#render_type_filters',
                                                                                                                                        'cjm_fasthtml_media_gallery/components/controls.py'),
                                                                'cjm_fasthtml_media_gallery.components.controls.render_view_toggle': ( 'components/controls.html#render_view_toggle',
                                                                                                                                       'cjm_fasthtml_media_gallery/components/controls.py')},
            'cjm_fasthtml_media_gallery.components.gallery': { 'cjm_fasthtml_media_gallery.components.gallery.render_gallery_content': ( 'components/gallery.html#render_gallery_content',
                                                                                                                                         'cjm_fasthtml_media_gallery/components/gallery.py'),
                                                               'cjm_fasthtml_media_gallery.components.gallery.render_media_gallery': ( 'components/gallery.html#render_media_gallery',
                                                                                                                                       'cjm_fasthtml_media_gallery/components/gallery.py')},
            'cjm_fasthtml_media_gallery.components.grid_view': { 'cjm_fasthtml_media_gallery.components.grid_view._render_info_area': ( 'components/grid_view.html#_render_info_area',
                                                                                                                                        'cjm_fasthtml_media_gallery/components/grid_view.py'),
                                                                 'cjm_fasthtml_media_gallery.components.grid_view._render_selection_indicator': ( 'components/grid_view.html#_render_selection_indicator',
                                                                                                                                                  'cjm_fasthtml_media_gallery/components/grid_view.py'),
                                                                 'cjm_fasthtml_media_gallery.components.grid_view._render_thumbnail_area': ( 'components/grid_view.html#_render_thumbnail_area',
                                                                                                                                             'cjm_fasthtml_media_gallery/components/grid_view.py'),
                                                                 'cjm_fasthtml_media_gallery.components.grid_view._render_type_badge': ( 'components/grid_view.html#_render_type_badge',
                                                                                                                                         'cjm_fasthtml_media_gallery/components/grid_view.py'),
                                                                 'cjm_fasthtml_media_gallery.components.grid_view.render_grid_empty_state': ( 'components/grid_view.html#render_grid_empty_state',
                                                                                                                                              'cjm_fasthtml_media_gallery/components/grid_view.py'),
                                                                 'cjm_fasthtml_media_gallery.components.grid_view.render_grid_view': ( 'components/grid_view.html#render_grid_view',
                                                                                                                                       'cjm_fasthtml_media_gallery/components/grid_view.py'),
                                                                 'cjm_fasthtml_media_gallery.components.grid_view.render_media_card': ( 'components/grid_view.html#render_media_card',
                                                                                                                                        'cjm_fasthtml_media_gallery/components/grid_view.py')},
            'cjm_fasthtml_media_gallery.components.list_view': { 'cjm_fasthtml_media_gallery.components.list_view._render_cell': ( 'components/list_view.html#_render_cell',
                                                                                                                                   'cjm_fasthtml_media_gallery/components/list_view.py'),
                                                                 'cjm_fasthtml_media_gallery.components.list_view.render_list_empty_state': ( 'components/list_view.html#render_list_empty_state',
                                                                                                                                              'cjm_fasthtml_media_gallery/components/list_view.py'),
                                                                 'cjm_fasthtml_media_gallery.components.list_view.render_list_header': ( 'components/list_view.html#render_list_header',
                                                                                                                                         'cjm_fasthtml_media_gallery/components/list_view.py'),
                                                                 'cjm_fasthtml_media_gallery.components.list_view.render_list_row': ( 'components/list_view.html#render_list_row',
                                                                                                                                      'cjm_fasthtml_media_gallery/components/list_view.py'),
                                                                 'cjm_fasthtml_media_gallery.components.list_view.render_list_view': ( 'components/list_view.html#render_list_view',
                                                                                                                                       'cjm_fasthtml_media_gallery/components/list_view.py')},
            'cjm_fasthtml_media_gallery.components.players': { 'cjm_fasthtml_media_gallery.components.players.is_text_previewable': ( 'components/players.html#is_text_previewable',
                                                                                                                                      'cjm_fasthtml_media_gallery/components/players.py'),
                                                               'cjm_fasthtml_media_gallery.components.players.read_text_content': ( 'components/players.html#read_text_content',
                                                                                                                                    'cjm_fasthtml_media_gallery/components/players.py'),
                                                               'cjm_fasthtml_media_gallery.components.players.render_audio_player': ( 'components/players.html#render_audio_player',
                                                                                                                                      'cjm_fasthtml_media_gallery/components/players.py'),
                                                               'cjm_fasthtml_media_gallery.components.players.render_document_preview': ( 'components/players.html#render_document_preview',
                                                                                                                                          'cjm_fasthtml_media_gallery/components/players.py'),
                                                               'cjm_fasthtml_media_gallery.components.players.render_image_viewer': ( 'components/players.html#render_image_viewer',
                                                                                                                                      'cjm_fasthtml_media_gallery/components/players.py'),
                                                               'cjm_fasthtml_media_gallery.components.players.render_media_player': ( 'components/players.html#render_media_player',
                                                                                                                                      'cjm_fasthtml_media_gallery/components/players.py'),
                                                               'cjm_fasthtml_media_gallery.components.players.render_text_viewer': ( 'components/players.html#render_text_viewer',
                                                                                                                                     'cjm_fasthtml_media_gallery/components/players.py'),
                                                               'cjm_fasthtml_media_gallery.components.players.render_video_player': ( 'components/players.html#render_video_player',
                                                                                                                                      'cjm_fasthtml_media_gallery/components/players.py')},
            'cjm_fasthtml_media_gallery.components.preview': { 'cjm_fasthtml_media_gallery.components.preview._render_info_panel': ( 'components/preview.html#_render_info_panel',
                                                                                                                                     'cjm_fasthtml_media_gallery/components/preview.py'),
                                                               'cjm_fasthtml_media_gallery.components.preview._render_preview_footer': ( 'components/preview.html#_render_preview_footer',
                                                                                                                                         'cjm_fasthtml_media_gallery/components/preview.py'),
                                                               'cjm_fasthtml_media_gallery.components.preview._render_preview_header': ( 'components/preview.html#_render_preview_header',
                                                                                                                                         'cjm_fasthtml_media_gallery/components/preview.py'),
                                                               'cjm_fasthtml_media_gallery.components.preview.render_preview_content': ( 'components/preview.html#render_preview_content',
                                                                                                                                         'cjm_fasthtml_media_gallery/components/preview.py'),
                                                               'cjm_fasthtml_media_gallery.components.preview.render_preview_modal': ( 'components/preview.html#render_preview_modal',
                                                                                                                                       'cjm_fasthtml_media_gallery/components/preview.py')},
            'cjm_fasthtml_media_gallery.core.config': { 'cjm_fasthtml_media_gallery.core.config.CardSize': ( 'core/config.html#cardsize',
                                                                                                             'cjm_fasthtml_media_gallery/core/config.py'),
                                                        'cjm_fasthtml_media_gallery.core.config.FilterConfig': ( 'core/config.html#filterconfig',
                                                                                                                 'cjm_fasthtml_media_gallery/core/config.py'),
                                                        'cjm_fasthtml_media_gallery.core.config.FilterConfig.matches': ( 'core/config.html#filterconfig.matches',
                                                                                                                         'cjm_fasthtml_media_gallery/core/config.py'),
                                                        'cjm_fasthtml_media_gallery.core.config.GalleryCallbacks': ( 'core/config.html#gallerycallbacks',
                                                                                                                     'cjm_fasthtml_media_gallery/core/config.py'),
                                                        'cjm_fasthtml_media_gallery.core.config.GalleryConfig': ( 'core/config.html#galleryconfig',
                                                                                                                  'cjm_fasthtml_media_gallery/core/config.py'),
                                                        'cjm_fasthtml_media_gallery.core.config.GalleryConfig.can_select': ( 'core/config.html#galleryconfig.can_select',
                                                                                                                             'cjm_fasthtml_media_gallery/core/config.py'),
                                                        'cjm_fasthtml_media_gallery.core.config.GridConfig': ( 'core/config.html#gridconfig',
                                                                                                               'cjm_fasthtml_media_gallery/core/config.py'),
                                                        'cjm_fasthtml_media_gallery.core.config.ListColumn': ( 'core/config.html#listcolumn',
                                                                                                               'cjm_fasthtml_media_gallery/core/config.py'),
                                                        'cjm_fasthtml_media_gallery.core.config.ListConfig': ( 'core/config.html#listconfig',
                                                                                                               'cjm_fasthtml_media_gallery/core/config.py'),
                                                        'cjm_fasthtml_media_gallery.core.config.PaginationConfig': ( 'core/config.html#paginationconfig',
                                                                                                                     'cjm_fasthtml_media_gallery/core/config.py'),
                                                        'cjm_fasthtml_media_gallery.core.config.PreviewConfig': ( 'core/config.html#previewconfig',
                                                                                                                  'cjm_fasthtml_media_gallery/core/config.py'),
                                                        'cjm_fasthtml_media_gallery.core.config.SelectionMode': ( 'core/config.html#selectionmode',
                                                                                                                  'cjm_fasthtml_media_gallery/core/config.py'),
                                                        'cjm_fasthtml_media_gallery.core.config.ViewMode': ( 'core/config.html#viewmode',
                                                                                                             'cjm_fasthtml_media_gallery/core/config.py')},
            'cjm_fasthtml_media_gallery.core.html_ids': { 'cjm_fasthtml_media_gallery.core.html_ids.GalleryHtmlIds': ( 'core/html_ids.html#galleryhtmlids',
                                                                                                                       'cjm_fasthtml_media_gallery/core/html_ids.py'),
                                                          'cjm_fasthtml_media_gallery.core.html_ids.GalleryHtmlIds.as_selector': ( 'core/html_ids.html#galleryhtmlids.as_selector',
                                                                                                                                   'cjm_fasthtml_media_gallery/core/html_ids.py'),
                                                          'cjm_fasthtml_media_gallery.core.html_ids.GalleryHtmlIds.grid_item_id': ( 'core/html_ids.html#galleryhtmlids.grid_item_id',
                                                                                                                                    'cjm_fasthtml_media_gallery/core/html_ids.py'),
                                                          'cjm_fasthtml_media_gallery.core.html_ids.GalleryHtmlIds.list_item_id': ( 'core/html_ids.html#galleryhtmlids.list_item_id',
                                                                                                                                    'cjm_fasthtml_media_gallery/core/html_ids.py')},
            'cjm_fasthtml_media_gallery.core.icons': { 'cjm_fasthtml_media_gallery.core.icons.get_gallery_icon': ( 'core/icons.html#get_gallery_icon',
                                                                                                                   'cjm_fasthtml_media_gallery/core/icons.py'),
                                                       'cjm_fasthtml_media_gallery.core.icons.get_media_type_icon': ( 'core/icons.html#get_media_type_icon',
                                                                                                                      'cjm_fasthtml_media_gallery/core/icons.py')},
            'cjm_fasthtml_media_gallery.patterns.pagination': { 'cjm_fasthtml_media_gallery.patterns.pagination.PaginationInfo': ( 'patterns/pagination.html#paginationinfo',
                                                                                                                                   'cjm_fasthtml_media_gallery/patterns/pagination.py'),
                                                                'cjm_fasthtml_media_gallery.patterns.pagination.PaginationInfo.end_index': ( 'patterns/pagination.html#paginationinfo.end_index',
                                                                                                                                             'cjm_fasthtml_media_gallery/patterns/pagination.py'),
                                                                'cjm_fasthtml_media_gallery.patterns.pagination.PaginationInfo.get_visible_pages': ( 'patterns/pagination.html#paginationinfo.get_visible_pages',
                                                                                                                                                     'cjm_fasthtml_media_gallery/patterns/pagination.py'),
                                                                'cjm_fasthtml_media_gallery.patterns.pagination.PaginationInfo.has_next': ( 'patterns/pagination.html#paginationinfo.has_next',
                                                                                                                                            'cjm_fasthtml_media_gallery/patterns/pagination.py'),
                                                                'cjm_fasthtml_media_gallery.patterns.pagination.PaginationInfo.has_prev': ( 'patterns/pagination.html#paginationinfo.has_prev',
                                                                                                                                            'cjm_fasthtml_media_gallery/patterns/pagination.py'),
                                                                'cjm_fasthtml_media_gallery.patterns.pagination.PaginationInfo.items_on_page': ( 'patterns/pagination.html#paginationinfo.items_on_page',
                                                                                                                                                 'cjm_fasthtml_media_gallery/patterns/pagination.py'),
                                                                'cjm_fasthtml_media_gallery.patterns.pagination.PaginationInfo.start_index': ( 'patterns/pagination.html#paginationinfo.start_index',
                                                                                                                                               'cjm_fasthtml_media_gallery/patterns/pagination.py'),
                                                                'cjm_fasthtml_media_gallery.patterns.pagination.PaginationInfo.total_pages': ( 'patterns/pagination.html#paginationinfo.total_pages',
                                                                                                                                               'cjm_fasthtml_media_gallery/patterns/pagination.py'),
                                                                'cjm_fasthtml_media_gallery.patterns.pagination._page_button': ( 'patterns/pagination.html#_page_button',
                                                                                                                                 'cjm_fasthtml_media_gallery/patterns/pagination.py'),
                                                                'cjm_fasthtml_media_gallery.patterns.pagination.render_pagination': ( 'patterns/pagination.html#render_pagination',
                                                                                                                                      'cjm_fasthtml_media_gallery/patterns/pagination.py'),
                                                                'cjm_fasthtml_media_gallery.patterns.pagination.render_pagination_info': ( 'patterns/pagination.html#render_pagination_info',
                                                                                                                                           'cjm_fasthtml_media_gallery/patterns/pagination.py')},
            'cjm_fasthtml_media_gallery.routes.handlers': { 'cjm_fasthtml_media_gallery.routes.handlers.GalleryState': ( 'routes/handlers.html#gallerystate',
                                                                                                                         'cjm_fasthtml_media_gallery/routes/handlers.py'),
                                                            'cjm_fasthtml_media_gallery.routes.handlers.GalleryState.from_dict': ( 'routes/handlers.html#gallerystate.from_dict',
                                                                                                                                   'cjm_fasthtml_media_gallery/routes/handlers.py'),
                                                            'cjm_fasthtml_media_gallery.routes.handlers.GalleryState.to_dict': ( 'routes/handlers.html#gallerystate.to_dict',
                                                                                                                                 'cjm_fasthtml_media_gallery/routes/handlers.py'),
                                                            'cjm_fasthtml_media_gallery.routes.handlers._handle_filter_type': ( 'routes/handlers.html#_handle_filter_type',
                                                                                                                                'cjm_fasthtml_media_gallery/routes/handlers.py'),
                                                            'cjm_fasthtml_media_gallery.routes.handlers._handle_page': ( 'routes/handlers.html#_handle_page',
                                                                                                                         'cjm_fasthtml_media_gallery/routes/handlers.py'),
                                                            'cjm_fasthtml_media_gallery.routes.handlers._handle_preview': ( 'routes/handlers.html#_handle_preview',
                                                                                                                            'cjm_fasthtml_media_gallery/routes/handlers.py'),
                                                            'cjm_fasthtml_media_gallery.routes.handlers._handle_preview_nav': ( 'routes/handlers.html#_handle_preview_nav',
                                                                                                                                'cjm_fasthtml_media_gallery/routes/handlers.py'),
                                                            'cjm_fasthtml_media_gallery.routes.handlers._handle_select': ( 'routes/handlers.html#_handle_select',
                                                                                                                           'cjm_fasthtml_media_gallery/routes/handlers.py'),
                                                            'cjm_fasthtml_media_gallery.routes.handlers._handle_toggle_view': ( 'routes/handlers.html#_handle_toggle_view',
                                                                                                                                'cjm_fasthtml_media_gallery/routes/handlers.py'),
                                                            'cjm_fasthtml_media_gallery.routes.handlers.init_router': ( 'routes/handlers.html#init_router',
                                                                                                                        'cjm_fasthtml_media_gallery/routes/handlers.py')},
            'cjm_fasthtml_media_gallery.serving.mounter': { 'cjm_fasthtml_media_gallery.serving.mounter.DirectoryMounter': ( 'serving/mounter.html#directorymounter',
                                                                                                                             'cjm_fasthtml_media_gallery/serving/mounter.py'),
                                                            'cjm_fasthtml_media_gallery.serving.mounter.DirectoryMounter.__init__': ( 'serving/mounter.html#directorymounter.__init__',
                                                                                                                                      'cjm_fasthtml_media_gallery/serving/mounter.py'),
                                                            'cjm_fasthtml_media_gallery.serving.mounter.DirectoryMounter._generate_prefix': ( 'serving/mounter.html#directorymounter._generate_prefix',
                                                                                                                                              'cjm_fasthtml_media_gallery/serving/mounter.py'),
                                                            'cjm_fasthtml_media_gallery.serving.mounter.DirectoryMounter._mount_directory': ( 'serving/mounter.html#directorymounter._mount_directory',
                                                                                                                                              'cjm_fasthtml_media_gallery/serving/mounter.py'),
                                                            'cjm_fasthtml_media_gallery.serving.mounter.DirectoryMounter._remove_existing_mounts': ( 'serving/mounter.html#directorymounter._remove_existing_mounts',
                                                                                                                                                     'cjm_fasthtml_media_gallery/serving/mounter.py'),
                                                            'cjm_fasthtml_media_gallery.serving.mounter.DirectoryMounter.create_url_getter': ( 'serving/mounter.html#directorymounter.create_url_getter',
                                                                                                                                               'cjm_fasthtml_media_gallery/serving/mounter.py'),
                                                            'cjm_fasthtml_media_gallery.serving.mounter.DirectoryMounter.get_mounted_directories': ( 'serving/mounter.html#directorymounter.get_mounted_directories',
                                                                                                                                                     'cjm_fasthtml_media_gallery/serving/mounter.py'),
                                                            'cjm_fasthtml_media_gallery.serving.mounter.DirectoryMounter.get_url': ( 'serving/mounter.html#directorymounter.get_url',
                                                                                                                                     'cjm_fasthtml_media_gallery/serving/mounter.py'),
                                                            'cjm_fasthtml_media_gallery.serving.mounter.DirectoryMounter.is_mounted': ( 'serving/mounter.html#directorymounter.is_mounted',
                                                                                                                                        'cjm_fasthtml_media_gallery/serving/mounter.py'),
                                                            'cjm_fasthtml_media_gallery.serving.mounter.DirectoryMounter.mount': ( 'serving/mounter.html#directorymounter.mount',
                                                                                                                                   'cjm_fasthtml_media_gallery/serving/mounter.py'),
                                                            'cjm_fasthtml_media_gallery.serving.mounter.DirectoryMounter.unmount_all': ( 'serving/mounter.html#directorymounter.unmount_all',
                                                                                                                                         'cjm_fasthtml_media_gallery/serving/mounter.py')}}}
